.. _roadmap_toplevel:

===========================
Stalker Development Roadmap
===========================

This section describes the direction Stalker is going.

Roadmap Based on Versions
=========================

Below you can find the roadmap based on the version

0.1.0:
------

 * A complete working set of models in SOM which are using
   SQLAlchemy.ext.declarative.

0.2.0:
------
 * Web interface
 * Complete ProdAM capabilities.

0.3.0:
------
 * Complete working Event system
